# Mogistics

## What is Mogistics ?

Mogistics is a designed app to help u manage and supervise the different services of your logistics company .
With Mogistics installed your smartphone and computer become the point where the office meets the field.

## Author :

ZITOUNI Sarah

## Structure

Let's put you in context, a site (= company) is made of cells. A cell is made of aisles. An aisle is a set of bins. A bin is a kind of box where items are stowed.
[To be continued ..]

##

## Project status

Actions Left :

- Finish the graphic interface
  - Set the backgroud image in a better way
  - Find a way to save in a variable the logins/ passwords
- Link the database to the app to set the authentification check
-

## UML Diagram

https://lucid.app/lucidchart/19eaf119-0d7f-4c47-b462-c7963d136fda/edit?viewport_loc=-386%2C-527%2C3271%2C1482%2C0_0&invitationId=inv_1f495974-3287-4da6-a79b-01ae4a2a7ae4
